<?php

namespace Drupal\commerce_order2pdf\Form;

use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Commerce Order2pdf settings form.
 */
class CommerceOrder2pdfSettingsForm extends ConfigFormBase {

  /**
   * The module handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Constructs a new CommerceOrder2pdfSettingsForm object.
   *
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $moduleHandler
   *   The module handler service.
   */
  public function __construct(ModuleHandlerInterface $moduleHandler) {
    $this->moduleHandler = $moduleHandler;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('module_handler')
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['commerce_order2pdf.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'commerce_order2pdf_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('commerce_order2pdf.settings');
    $default_header = "
    <table>
    <tr>
      <td>
        [site:name]
      <td>
      <td style=\"text-align: right\">
        <b>Order nr: [commerce-order:order-number]</b><br />
        <b>Created at:</b> [commerce-order:created]<br />
      </td>
    </tr>
    </table>";

    $query_destination = ['query' => $this->getDestinationArray()];
    $form['order2pdf_info'] = [
      '#type' => 'markup',
      '#markup' => '<p>' . $this->t(
          'Edit Order2pdf %order_view and %line_items views as needed.', [
            '%order_view' => Link::fromTextAndUrl($this->t('order view'), Url::fromRoute('entity.view.edit_form', ['view' => 'commerce_order2pdf'], $query_destination))->toString(),
            '%line_items' => Link::fromTextAndUrl($this->t('line items'), Url::fromRoute('entity.view.edit_form', ['view' => 'commerce_order2pdf_line_item_table'], $query_destination))->toString(),
          ]
      ) . '</p>',
    ];

    $form['order2pdf_pdf_header'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Set PDF order header'),
      '#cols' => 5,
      '#default_value' => $config->get('pdf_header') ?: $default_header,
      '#description' => $this->t('Create header to your commerce order PDF file. Just write some HTML and use tokens.'),
    ];

    $form['order2pdf_pdf_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Set PDF file name'),
      '#default_value' => $config->get('pdf_title') ?: 'Order_[commerce-order:order-id]',
      '#description' => $this->t('Add your own title for generated PDF file.'),
      '#required' => TRUE,
    ];

    $form['order2pdf_pdf_style_file'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Inline CSS files'),
      '#default_value' => $config->get('pdf_style_file') ?: $this->moduleHandler->getPath('commerce_order2pdf') . '/commerce_order2pdf.css',
      '#required' => TRUE,
    ];

    $form['token_help'] = [
      '#theme' => 'token_tree_link',
      '#token_types' => ['commerce-order'],
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('commerce_order2pdf.settings');

    $config->set('pdf_header', $form_state->getValue('order2pdf_pdf_header'))
      ->set('pdf_title', $form_state->getValue('order2pdf_pdf_title'))
      ->set('pdf_style_file', $form_state->getValue('order2pdf_pdf_style_file'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
