<?php

namespace Drupal\commerce_order2pdf\Plugin\views\field;

use Drupal\Core\Url;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ResultRow;

/**
 * Field handler to present a PDF download link for orders.
 *
 * @ViewsField("commerce_order2pdf_field_order_pdf_link")
 */
class CommerceOrder2pdfFieldOrderPdfLink extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function query() {
    // Do nothing -- to override the parent query.
  }

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {

    $order = $values->_entity;

    // Generate a hash for the PDF link.
    $hash = hash('md5', $order->id() . $order->get('created')->value);

    // Customize the text for the PDF download link.
    $text = !empty($this->options['text']) ? $this->options['text'] : $this->t('Download');

    // Construct the PDF download URL with the hash as a path segment.
    $url = Url::fromRoute(
          'commerce_order2pdf.view', [
            'commerce_order' => $order->id(),
            'hash' => $hash,
          ]
      )->setAbsolute()->toString();

    // Generate and return the PDF download link.
    return [
      '#type' => 'link',
      '#title' => $text,
      '#url' => Url::fromUri($url),
    ];
  }

}
